@@ -1,6 +1,6 @@
 package Validator::Custom;
 
-our $VERSION = '0.1410';
+our $VERSION = '0.1411';
 
 use 5.008001;
 use strict;
@@ -82,6 +82,202 @@ my $rule = [                              # 1 Rule is array ref
 
 EOS
 
+sub _parse_random_string_rule {
+    my $self = shift;
+    
+    # Rule
+    my $rule = ref $_[0] eq 'HASH' ? $_[0] : {@_};
+    
+    # Result
+    my $result = {};
+    
+    # Parse string rule
+    foreach my $name (keys %$rule) {
+        
+        # Pettern
+        my $pattern = $rule->{$name};
+        $pattern = '' unless $pattern;
+        
+        # State
+        my $state = 'character';
+
+        # Count
+        my $count = '';
+        
+        # Chacacter sets
+        my $csets = [];
+        my $cset = [];
+        
+        # Parse pattern
+        my $c;
+        while (defined ($c = substr($pattern, 0, 1, '')) && length $c) {
+            
+            # Character class
+            if ($state eq 'character_class') {
+                if ($c eq ']') {
+                    $state = 'character';
+                    push @$csets, $cset;
+                    $cset = [];
+                    $state = 'character';
+                }
+                else {
+                    push @$cset, $c;
+                }
+            }
+            
+            # Count
+            elsif ($state eq 'count') {
+                if ($c eq '}') {
+                    $count = 1 if $count < 1;
+                    for (my $i = 0; $i < $count - 1; $i++) {
+                        push @$csets, [@{$csets->[-1] || ['']}];
+                    }
+                    $count = '';
+                    $state = 'character';
+                }
+                else {
+                    $count .= $c;
+                }
+            }
+            
+            # Character
+            else {
+                if ($c eq '[') {
+                    $state = 'character_class';
+                }
+                elsif ($c eq '{') {
+                    $state = 'count';
+                }
+                else {
+                    push @$csets, [$c];
+                }
+            }
+        }
+        
+        # Add Charcter sets
+        $result->{$name} = $csets;
+    }
+    
+    return $result;
+}
+
+sub js_fill_form_button {
+    my ($self, $rule) = @_;
+    
+    my $r = $self->_parse_random_string_rule($rule);
+    
+    require JSON;
+    my $r_json = JSON->new->encode($r);
+    
+    my $javascript = << "EOS";
+  (function () {
+
+    var rule = $r_json;
+  
+    var create_random_value = function (rule, name) {
+      var patterns = rule[name];
+      if (patterns === undefined) {
+        return "";
+      }
+      
+      var value = "";
+      for (var i = 0; i < patterns.length; i++) {
+        var pattern = patterns[i];
+        var num = Math.floor(Math.random() * pattern.length);
+        value = value + pattern[num];
+      }
+      
+      return value;
+    };
+    
+  	var addEvent = (function(){
+  	  if(document.addEventListener) {
+  	    return function(node,type,handler){
+  	      node.addEventListener(type,handler,false);
+  	    };
+  	  } else if (document.attachEvent) {
+  	    return function(node,type,handler){
+  	      node.attachEvent('on' + type, function(evt){
+  	        handler.call(node, evt);
+  	      });
+  	    };
+  	  }
+  	})();
+  	
+  	var button = document.createElement("input");
+  	button.setAttribute("type","button");
+  	button.setAttribute("value","Fill Form");
+    document.body.insertBefore(button, document.body.firstChild)
+
+    addEvent(
+      button,
+      "click",
+      function () {
+        
+        var input_elems = document.getElementsByTagName('input');
+        var radio_names = {};
+        var checkbox_names = {};
+        for (var i = 0; i < input_elems.length; i++) {
+          var e = input_elems[i];
+
+          var name = e.getAttribute("name");
+          var type = e.getAttribute("type");
+          if (type === "text" || type === "hidden" || type === "password") {
+            var value = create_random_value(rule, name);
+            e.setAttribute("value", value);
+          }
+          else if (type === "checkbox") {
+            e.checked = Math.floor(Math.random() * 2) ? true : false;
+          }
+          else if (type === "radio") {
+            radio_names[name] = 1;
+          }
+        }
+        
+        for (name in radio_names) {
+          var elems = document.getElementsByName(name);
+          var num = Math.floor(Math.random() * elems.length);
+          elems[num].checked = true;
+        }
+        
+        var textarea_elems = document.getElementsByTagName("textarea");
+        for (var i = 0; i < textarea_elems.length; i++) {
+          var e = textarea_elems[i];
+          
+          var name = e.getAttribute("name");
+          var value = create_random_value(rule, name);
+          
+          var text = document.createTextNode(value);
+          
+          if (e.firstChild) {
+            e.removeChild(e.firstChild);
+          }
+          
+          e.appendChild(text);
+        }
+        
+        var select_elems = document.getElementsByTagName("select");
+        for (var i = 0; i < select_elems.length; i++) {
+          var e = select_elems[i];
+          var options = e.options;
+          if (e.multiple) {
+            for (var k = 0; k < options.length; k++) {
+              options[k].selected = Math.floor(Math.random() * 2) ? true : false;
+            }
+          }
+          else {
+            var num = Math.floor(Math.random() * options.length);
+            e.selectedIndex = num;
+          }
+        }
+      }
+    );
+  })();
+EOS
+
+    return $javascript;
+}
+
 sub register_constraint {
     my $self = shift;
     
@@ -607,6 +803,20 @@ Syntax of rule.
 L<Validator::Custom> inherits all methods from L<Object::Simple>
 and implements the following new ones.
 
+=head2 C<(experimental) js_fill_form_button>
+
+    my $js_code = $self->js_fill_form_button(
+        mail => '[abc]{3}@[abc]{2}.com,
+        title => '[pqr]{5}'
+    );
+
+Create button javascript source code to fill form at random
+using pattern like regular expression.
+And checkbox radio group and list box also is automatically selected.
+This help you to input form in tests.
+
+Note that this methos require L<JSON> module.
+
 =head2 C<validate>
 
     $result = $vc->validate($data, $rule);
